@@ -68,6 +68,9 @@ class DiceLoss(nn.Module):
             str format, read them from a file. Defaults to None.
         loss_weight (float, optional): Weight of the loss. Default to 1.0.
         ignore_index (int | None): The label index to be ignored. Default: 255.
+        loss_name (str, optional): Name of the loss item. If you want this loss
+            item to be included into the backward graph, `loss_` must be the
+            prefix of the name. Defaults to 'loss_dice'.
     """
 
     def __init__(self,
@@ -77,6 +80,7 @@ class DiceLoss(nn.Module):
                  class_weight=None,
                  loss_weight=1.0,
                  ignore_index=255,
+                 loss_name='loss_dice',
                  **kwards):
         super(DiceLoss, self).__init__()
         self.smooth = smooth
@@ -85,6 +89,7 @@ class DiceLoss(nn.Module):
         self.class_weight = get_class_weight(class_weight)
         self.loss_weight = loss_weight
         self.ignore_index = ignore_index
+        self._loss_name = loss_name
 
     def forward(self,
                 pred,
@@ -118,3 +123,17 @@ class DiceLoss(nn.Module):
             class_weight=class_weight,
             ignore_index=self.ignore_index)
         return loss
+
+    @property
+    def loss_name(self):
+        """Loss Name.
+
+        This function must be implemented and will return the name of this
+        loss function. This name will be used to combine different loss items
+        by simple sum operation. In addition, if you want this loss item to be
+        included into the backward graph, `loss_` must be the prefix of the
+        name.
+        Returns:
+            str: The name of this loss item.
+        """
+        return self._loss_name
