@@ -25,12 +25,6 @@ def test_vit_backbone():
         x = torch.randn(1, 196)
         VisionTransformer.resize_pos_embed(x, 512, 512, 224, 224, 'bilinear')
 
-    with pytest.raises(IndexError):
-        # forward inputs must be [N, C, H, W]
-        x = torch.randn(3, 30, 30)
-        model = VisionTransformer()
-        model(x)
-
     with pytest.raises(AssertionError):
         # The length of img_size tuple must be lower than 3.
         VisionTransformer(img_size=(224, 224, 224))
